/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { IClient, IDocumentMessage } from "@fluidframework/protocol-definitions";
import * as core from "@fluidframework/server-services-core";
export declare class KafkaOrdererConnection implements core.IOrdererConnection {
    private readonly producer;
    readonly tenantId: string;
    readonly documentId: string;
    readonly clientId: string;
    private readonly client;
    readonly maxMessageSize: number;
    readonly serviceConfiguration: core.IServiceConfiguration;
    static create(producer: core.IProducer, tenantId: string, documentId: string, client: IClient, maxMessageSize: number, clientId: string, serviceConfiguration: core.IServiceConfiguration): Promise<KafkaOrdererConnection>;
    constructor(producer: core.IProducer, tenantId: string, documentId: string, clientId: string, client: IClient, maxMessageSize: number, serviceConfiguration: core.IServiceConfiguration);
    /**
     * Sends the client join op for this connection
     */
    connect(clientJoinMessageServerMetadata?: any): Promise<void>;
    /**
     * Orders the provided list of messages. The messages in the array are guaranteed to be ordered sequentially
     * so long as their total size fits under the maxMessageSize.
     */
    order(messages: IDocumentMessage[]): Promise<void>;
    /**
     * Sends the client leave op for this connection
     */
    disconnect(clientLeaveMessageServerMetadata?: any): Promise<void>;
    once(event: "error", listener: (...args: any[]) => void): void;
    private submitRawOperation;
}
export declare class KafkaOrderer implements core.IOrderer {
    private readonly producer;
    private readonly tenantId;
    private readonly documentId;
    private readonly maxMessageSize;
    private readonly serviceConfiguration;
    static create(producer: core.IProducer, tenantId: string, documentId: string, maxMessageSize: number, serviceConfiguration: core.IServiceConfiguration): Promise<KafkaOrderer>;
    constructor(producer: core.IProducer, tenantId: string, documentId: string, maxMessageSize: number, serviceConfiguration: core.IServiceConfiguration);
    connect(socket: core.IWebSocket, clientId: string, client: IClient): Promise<core.IOrdererConnection>;
    close(): Promise<void>;
}
export declare class KafkaOrdererFactory {
    private readonly producer;
    private readonly maxMessageSize;
    private readonly serviceConfiguration;
    private readonly ordererMap;
    constructor(producer: core.IProducer, maxMessageSize: number, serviceConfiguration: core.IServiceConfiguration);
    create(tenantId: string, documentId: string): Promise<core.IOrderer>;
    delete(tenantId: string, documentId: string): void;
}
//# sourceMappingURL=kafkaOrderer.d.ts.map